[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/maria-yankova/abaqus-parse/HEAD)

# abaqus-parse

[![PyPI version](https://badge.fury.io/py/abaqus-parse.svg)](https://badge.fury.io/py/abaqus-parse)

Abaqus input and output file readers and writers. 

